@@ -23,7 +23,7 @@ package Net::FullAuto::ISets::Amazon::GNUSocial_is;
 
 our $VERSION='0.01';
 our $DISPLAY='GNU Social';
-our $CONNECT='ssh';
+our $CONNECT='secure';
 our $defaultInstanceType='t2.micro';
 
 my $service_and_cert_password='Full@ut0O1';
@@ -638,24 +638,36 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
    $ad='    function showFullAuto()%NL%'.
       '    {%NL%'.
       "        \$this->elementStart(%SQ%div%SQ%, array(%SQ%id%SQ% => %SQ%fullauto%SQ%));%NL%".
-      "        \$image    = common_config(%SQ%fullauto%SQ%, %SQ%image%SQ%);%NL%".
       "        \$this->element(%SQ%img%SQ%, array(%SQ%id%SQ% => %SQ%fullauto%SQ%,%NL%".
       "                                    %SQ%src%SQ% => Theme::path(%SQ%fullauto_clickable_image.png%SQ%),%NL%".
       "                                    %SQ%alt%SQ% => common_config(%SQ%fullauto%SQ%, %SQ%title%SQ%),%NL%".
       "                                    %SQ%width%SQ% => %SQ%83%SQ%,%NL%".
       "                                    %SQ%height%SQ% => %SQ%40%SQ%));%NL%".
+      "        \$this->text(%SQ% %SQ%);%NL%".
+      "        \$this->elementStart(%SQ%a%SQ%, array(%SQ%class%SQ% => %SQ%fullauto url%SQ%,%NL%".
+      "                                        %SQ%href%SQ% => common_config(%SQ%fullauto%SQ%, %SQ%url%SQ%)));%NL%".
+      "        \$link = sprintf(%SQ%<a class=\"fullauto_image\" rel=\"fullauto\" href=\"%1\$s\">%2\$s</a>%SQ%,%NL%".
+      "                        htmlspecialchars(common_config(%SQ%fullauto%SQ%, %SQ%url%SQ%)),%NL%".
+      "                        htmlspecialchars(common_config(%SQ%fullauto%SQ%, %SQ%title%SQ%)));%NL%".
+      "        \$this->raw(\@sprintf(\$link));%NL%".
+      "        \$this->elementEnd(%SQ%a%SQ%);".
       "        \$this->elementEnd(%SQ%div%SQ%);%NL%".
       "    }%NL%";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
       "\'/function showFooter/i$ad\' /var/www/gnusocial/lib/action.php");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
-       '/var/www/gnusocial/lib/action.php');
+      '/var/www/gnusocial/lib/action.php');
    ($stdout,$stderr)=$handle->cmd(
-       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
-       "/var/www/gnusocial/lib/action.php");
+      "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
+      "/var/www/gnusocial/lib/action.php");
    $handle->cmd_raw(
-       "${sudo}sed -i 's#\\(^function showFullAuto[(][)]$\\\)#    \\1#' ".
-       '/var/www/gnusocial/lib/action.php');
+      "${sudo}sed -i 's#\\(^function showFullAuto[(][)]$\\\)#    \\1#' ".
+      '/var/www/gnusocial/lib/action.php');
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "\'/showContentLic/ashowFullAuto();\' /var/www/gnusocial/lib/action.php");
+   $handle->cmd_raw(
+      "${sudo}sed -i 's#\\(^showFullAuto[(][)]$\\\)#    \\1#' ".
+      '/var/www/gnusocial/lib/action.php');
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
    #          and replace these characters with thier HEX
